# install

This package requires `Python>=3.5`!  

## official

1. run `python3 -m pip install --user nichtparasoup`

## nightly

1. have git installed.
1. run `python3 -m pip install --user --upgrade https://github.com/k4cg/nichtparasoup.git`

## for development / testing

1. have git installed
1. clone the source from https://github.com/k4cg/nichtparasoup.git
1. run `python3 -m pip install --user --editable .[development,testing]` from cloned project's root dir.

## troubleshooting

if you find yourself having issues on install, see [requirement docs](requirements.md)
